#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
from pyramid.view import view_config
from onf_website.component.theme.interfaces import IThemesManagerTarget, IThemesManager
from pyams_form.form import AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.layer import IPyAMSLayer
from pyams_skin.viewlet.menu import MenuItem
from pyams_utils.interfaces.data import IObjectData
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogEditForm
from pyams_zmi.interfaces.menu import IPropertiesMenu
from pyams_zmi.layer import IAdminLayer

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces

# import packages
from z3c.form import field
from zope.interface import alsoProvides

from onf_website import _


@viewlet_config(name='themes-manager.menu', context=IThemesManagerTarget, layer=IAdminLayer,
                manager=IPropertiesMenu, permission='system.view', weight=200)
class ThemesManagerMenu(MenuItem):
    """Themes menu"""

    label = _("Themes...")
    icon_class = 'fa-tags'
    url = 'themes.html'
    modal_target = True


@pagelet_config(name='themes.html', context=IThemesManagerTarget, layer=IPyAMSLayer, permission='system.view')
class ThemesManagerEditForm(AdminDialogEditForm):
    """Themes manager edit form"""

    legend = _("Selected themes")

    fields = field.Fields(IThemesManager)
    ajax_handler = 'themes.json'
    edit_permission = 'onf.ManageSiteRoot'

    def updateWidgets(self, prefix=None):
        super(ThemesManagerEditForm, self).updateWidgets(prefix)
        widget = self.widgets['extract_name']
        widget.object_data = {'ams-plugins': 'onf_website',
                              'ams-plugin-onf_website-src': '/--static--/onf_website/js/website{MyAMS.devext}.js',
                              'ams-plugin-onf_website-callback': 'ONF.Skin.themes.initExtracts',
                              'ams-plugin-onf_website-async': 'false'}
        alsoProvides(widget, IObjectData)


@view_config(name='themes.json', context=IThemesManagerTarget, request_type=IPyAMSLayer,
             permission='onf.ManageSiteRoot', renderer='json', xhr=True)
class ThemesManagerAJAXEditForm(AJAXEditForm, ThemesManagerEditForm):
    """Themes manager edit form, JSON renderer"""
