#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from onf_website.base.interfaces import IBaseContent
from onf_website.root.interfaces import ISiteRoot
from pyams_workflow.interfaces import IWorkflowManagedContent
from zope.container.interfaces import IContainer

# import packages
from pyams_i18n.schema import I18nTextField
from pyams_security.schema import Principal, PrincipalsSet
from zope.container.constraints import containers, contains
from zope.interface import Interface, Attribute

from onf_website import _


class ISharedToolContainer(IBaseContent, IContainer):
    """Shared tools container"""

    containers(ISiteRoot)
    contains('.ISharedTool')


class ISharedTool(IBaseContent, IContainer):
    """Shared tool interface"""

    containers(ISharedToolContainer)
    contains('.ISharedData')

    shared_content_type = Attribute("Shared data content type")


class ISharedToolRoles(Interface):
    """Shared tool roles interface"""

    webmasters = PrincipalsSet(title=_("Webmasters"),
                               role_id='onf.Webmaster',
                               required=False)

    pilots = PrincipalsSet(title=_("Pilots"),
                           role_id='onf.Pilot',
                           required=False)

    managers = PrincipalsSet(title=_("Managers"),
                             role_id='onf.Manager',
                             required=False)

    contributors = PrincipalsSet(title=_("Contributors"),
                                 role_id='onf.Contributor',
                                 required=False)


class IWfSharedContent(IBaseContent):
    """Shared content interface"""

    content_type = Attribute("Content data type")

    owner = Principal(title=_("Content owner"),
                      description=_("Name of content owner"),
                      required=True)

    description = I18nTextField(title=_("Description"),
                                required=False)


class IWfSharedContentRoles(Interface):
    """Shared content roles"""

    readers = PrincipalsSet(title=_("Readers"),
                            role_id='onf.Reader',
                            required=False)

    guests = PrincipalsSet(title=_("Guests"),
                           role_id='onf.Guest',
                           required=False)


class ISharedContent(IWorkflowManagedContent):
    """Workflow managed shared data interface"""
